@@ -41,6 +41,7 @@ sub foo2 : Global {
 sub foo3 : Global {
     my( $self, $c ) = @_;
     $c->stash->{json_foo} = "\x{5bae}\x{5ddd}";
+    $c->component('View::JSON')->encoding('utf-8');
     $c->forward('TestApp::View::JSON');
 }
 
@@ -51,6 +52,13 @@ sub foo4 : Global {
     $c->forward('TestApp::View::JSON');
 }
 
+sub foo5 : Global {
+    my( $self, $c ) = @_;
+    $c->stash->{json_foo} = "\x{5bae}\x{5ddd}";
+    $c->component('View::JSON')->no_x_json_header(1);
+    $c->forward('TestApp::View::JSON');
+}
+
 sub finalize_error {
     my $c = shift;
     $c->res->header('X-Error' => $c->error->[0]);
